@@ -1,11 +1,10 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 let topkg_manual = "Topkg manual"
-let version = "v1.0.7"
+let version = "v1.0.8"
 
 (* Help manuals *)
 
@@ -343,14 +342,16 @@ let help man_format topic commands = match topic with
 | Some topic ->
     let topics = "topics" :: commands @ (List.map fst pages) in
     let topics = List.sort compare topics in
-    let conv, _ = Cmdliner.Arg.enum (List.rev_map (fun s -> (s, s)) topics) in
+    let conv =
+      Cmdliner.Arg.(conv_parser (enum (List.rev_map (fun s -> (s, s)) topics)))
+    in
     match conv topic with
-    | `Error e -> `Error (false, e)
-    | `Ok t when List.mem t commands -> `Help (man_format, Some t)
-    | `Ok t when t = "topics" ->
+    | Error (`Msg e) -> `Error (false, e)
+    | Ok t when List.mem t commands -> `Help (man_format, Some t)
+    | Ok t when t = "topics" ->
         Fmt.pr "@[<v>%a@]@." Fmt.(list string) topics;
         `Ok 0
-    | `Ok t ->
+    | Ok t ->
         let man = try List.assoc t pages with Not_found -> assert false in
         Fmt.pr "%a" (Cmdliner.Manpage.print man_format) man;
         `Ok 0
@@ -373,21 +374,5 @@ let man =
     `P "Use `topics' as $(i,TOPIC) to get a list of topics." ]
 
 let cmd =
-  Term.(ret (const help $ Term.man_format $ topic $ Term.choice_names)),
-  Term.info "help" ~doc ~exits ~man ~man_xrefs
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+  Cmd.v (Cmd.info "help" ~doc ~exits ~man ~man_xrefs) @@
+  Term.(ret (const help $ Arg.man_format $ topic $ Term.choice_names))
