@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -73,9 +72,9 @@ let until =
 let doc = "List commits to publish in the next distribution"
 let sdocs = Manpage.s_common_options
 let exits =
-  (Term.exit_info 0 ~doc:"changes have been detected.") ::
-  (Term.exit_info 1 ~doc:"no changes have been detected.") ::
-  Term.default_error_exits
+  (Cmd.Exit.info 0 ~doc:"changes have been detected.") ::
+  (Cmd.Exit.info 1 ~doc:"no changes have been detected.") ::
+  Cmd.Exit.defaults
 
 let man_xrefs = [ `Main ]
 let man =
@@ -84,21 +83,5 @@ let man =
         list of commits that define the changes for the next distribution." ]
 
 let cmd =
-  Term.(pure status $ Cli.setup $ Cli.pkg_file $ after $ until),
-  Term.info "status" ~doc ~sdocs ~exits ~man ~man_xrefs
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+  Cmd.v (Cmd.info "status" ~doc ~sdocs ~exits ~man ~man_xrefs) @@
+  Term.(const status $ Cli.setup $ Cli.pkg_file $ after $ until)
