@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Cmdliner
@@ -34,27 +33,12 @@ let man =
     `P "Daniel C. Buenzli, $(i,http://erratique.ch)"; ]
 
 let main =
-  Term.(ret (const main $ Cli.setup)),
-  Term.info "topkg" ~version:"v1.0.7" ~doc ~sdocs ~exits ~man
+  let default = Term.(ret (const main $ Cli.setup)) in
+  let info = Cmd.info "topkg" ~version:"v1.0.8" ~doc ~sdocs ~exits ~man in
+  Cmd.group ~default info cmds
 
 let main () =
   Topkg.Private.disable_main ();
-  Term.(exit_status @@ eval_choice main cmds)
+  Cmd.eval' main
 
-let () = main ()
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+let () = if !Sys.interactive then () else exit (main ())
