@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 (** Topkg package care.
@@ -14,9 +13,7 @@
     {b WARNING.} Do not use this API in your package description file, use
     only {!Topkg}. This API was not thoroughly designed, is not stable and
     may change even between minor versions of [topkg]. Use at your own
-    risk.
-
-    {e v1.0.7 - {{:https://erratique.ch/software/topkg }homepage}} *)
+    risk. *)
 
 open Bos_setup
 
@@ -134,7 +131,7 @@ module Opam : sig
   (** [ensure_publish ()] makes sure [opam-publish] is in the executable
       search PATH. *)
 
-  val submit : ?msg:string -> opam_file:Fpath.t -> (unit, R.msg) result
+  val submit : ?msg:string -> opam_file:Fpath.t -> unit -> (unit, R.msg) result
   (** [submit ~opam_file] submits the opam file [opam_file] with [opam-publish]
       and submission message [msg] (if any) to the OCaml opam repository. *)
 
@@ -488,20 +485,3 @@ module Delegate : sig
   val issue_close : Pkg.t -> id:string -> msg:string -> (unit, R.msg) result
   (** [issue_close p ~id ~msg] closes issue [id] with message [msg]. *)
 end
-
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
