@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Topkg_result
@@ -73,7 +72,7 @@ let help_cmd pkg =
   pr "%a@." pp_help ();
   Ok 0
 
-let version_cmd pkg = print_endline "topkg v1.0.7"; Ok 0
+let version_cmd pkg = print_endline "topkg v1.0.8"; Ok 0
 
 let build_cmd pkg kind args =
   let log_conf c =
@@ -239,7 +238,7 @@ let check_log ret =
 
 let setup_log_level level =
   Topkg_log.set_level level;
-  Topkg_log.info (fun m -> m "topkg v1.0.7, running main");
+  Topkg_log.info (fun m -> m "topkg v1.0.8, running main");
   Ok ()
 
 let main pkg =
@@ -291,19 +290,3 @@ let check_something_useful_happened () =
          occured or did you forget to call Topkg.Pkg.describe ?")
 
 let () = at_exit check_something_useful_happened
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
